Crate devgen_splitter

source

Structs

  • Represents a chunk of code containing one or more entities.
  • Represents a code entity with its associated metadata.
  • Configuration options for the devgen splitter.

Enums

  • Represents the different types of entities that can be identified in the code.

Functions

  • Splits the given code into chunks based on the provided options.