pub struct SplitOptions {
pub chunk_line_limit: usize,
pub enable_header: bool,
}Expand description
Options for splitting code into chunks
Fields
chunk_line_limit: usizeThe maximum number of lines for each code chunk.
This value determines the size of the “window” used when splitting the code into chunks. If a chunk exceeds this size, it will be divided into smaller chunks. A larger value results in fewer, larger chunks, while a smaller value produces more, smaller chunks.
enable_header: boolAuto Trait Implementations
impl Freeze for SplitOptions
impl RefUnwindSafe for SplitOptions
impl Send for SplitOptions
impl Sync for SplitOptions
impl Unpin for SplitOptions
impl UnwindSafe for SplitOptions