pub struct Chunk {
pub line_range: Range<usize>,
pub entities: Vec<Entity>,
}Expand description
Represents a chunk of code containing one or more entities.
A chunk is a section of the source code that may contain multiple entities and is defined by a range of line numbers.
Fields
line_range: Range<usize>The line range of the chunk in the source code
entities: Vec<Entity>The entities contained within this chunk